#!/usr/bin/env bash

cd "$(dirname "$0")"

# turn on verbose debugging output for parabuild logs.
exec 4>&1; export BASH_XTRACEFD=4; set -x
# make errors fatal
set -e
# complain about unset env variables
set -u

if [ -z "$AUTOBUILD" ] ; then 
    exit 1
fi

if [ "$OSTYPE" = "cygwin" ] ; then
    autobuild="$(cygpath -u $AUTOBUILD)"
else
    autobuild="$AUTOBUILD"
fi

top="$(pwd)"
stage="$(pwd)/stage"

mkdir -p $stage

# Load autobuild provided shell functions and variables
source_environment_tempfile="$stage/source_environment.sh"
"$autobuild" source_environment > "$source_environment_tempfile"
. "$source_environment_tempfile"

NLOHMANNJSON_SOURCE_DIR="json"

build=${AUTOBUILD_BUILD_ID:=0}

# Create the staging folders
mkdir -p "$stage/include/nlohmann"

pushd "$NLOHMANNJSON_SOURCE_DIR"
    case "$AUTOBUILD_PLATFORM" in
        common*)
            cp -a include/nlohmann/* "$stage/include/nlohmann"

            VERSION_HEADER_FILE="include/nlohmann/json.hpp"
            version_major=$(sed -n -E 's/#define NLOHMANN_JSON_VERSION_MAJOR ([a-z0-9.]+)/\1/p' "${VERSION_HEADER_FILE}")
            version_minor=$(sed -n -E 's/#define NLOHMANN_JSON_VERSION_MINOR ([a-z0-9.]+)/\1/p' "${VERSION_HEADER_FILE}")
            version_patch=$(sed -n -E 's/#define NLOHMANN_JSON_VERSION_PATCH ([a-z0-9.]+)/\1/p' "${VERSION_HEADER_FILE}")
            echo "${version_major}.${version_minor}.${version_patch}.${build}" > "${stage}/VERSION.txt"
        ;;
    esac
    mkdir -p "$stage/LICENSES"
    cp LICENSE.MIT "$stage/LICENSES/modernjson.txt"
popd
